'use client';

import Image from 'next/image';
import { motion } from 'framer-motion';

import blahaj from '../../public/blahaj.webp';
import gitlab from '../../public/gitlab.svg';
import picrew from '../../public/picrew.png';

export default function Home() {
  const date = new Date();
  const [day, month, year] = [
    date.getDate(),
    date.getMonth(),
    date.getFullYear(),
  ];

  const [C, M, Y, K] = [day / 31, month / 12, year / 10000, (year % 100) / 100];

  const R = Math.round(255 * (1 - C) * (1 - K));
  const G = Math.round(255 * (1 - M) * (1 - K));
  const B = Math.round(255 * (1 - Y) * (1 - K));

  const RGB = R.toString(16) + G.toString(16) + B.toString(16);

  const items = [
    {
      name: 'eParafia',
      class_: 'hover:border-[#466e83] hover:bg-[#365e70]',
      link: 'https://eparafia.eu',
    },
    {
      name: 'Podlaski ZBS',
      class_: 'hover:border-[#7c626c] hover:bg-[#6f6f71]',
      link: 'https://podlaskizbs.pl',
    },
    {
      name: 'Ikubi',
      class_: 'hover:border-[#7c626c] hover:bg-[#6f6f71]',
      link: 'https://ikubi.pl',
    },
    {
      name: 'nyaa',
      class_: 'hover:border-[#466e83] hover:bg-[#365e70]',
      git: 'https://gitlab.com/yaemiku/nyaa',
      desc: `it's a script, dummy!`,
    },
    {
      name: 'Puchar LO V',
      class_: 'hover:border-[#7f7f84] hover:bg-[#6f6f71]',
      link: 'https://puchar.lo5.bielsko.pl',
      git: 'https://gitlab.com/yaemiku/puchar',
      full: true,
    },
  ];

  return (
    <div className="p-4 mx-auto mt-4 max-w-screen-md prose prose-zinc prose-invert">
      <header className="flex flex-col justify-around items-center px-4">
        <div>
          <motion.div
            animate={{
              left: 0,
              right: 0,
            }}
            transition={
              {
                // ease: 'easeIn',
              }
            }
            className="flex flex-col max-w-[100vw] absolute h-16 my-28 z-10 shadow-2xl"
          >
            <div className="grow bg-[#55CDFC] z-0"></div>
            <div className="grow bg-[#F7A8B8] z-0"></div>
            <div className="z-0 bg-white grow"></div>
            <div className="grow bg-[#F7A8B8] z-0"></div>
            <div className="grow bg-[#55CDFC] z-0"></div>
          </motion.div>
          <div className="relative z-20 mx-auto w-72">
            <Image
              src={picrew}
              alt="My Picrew"
              className="rounded-full shadow-2xl pointer-events-none select-none"
              priority
            />
          </div>
        </div>
        <div className="flex flex-col gap-y-4 items-center my-4 w-full">
          <h1 className="flex gap-x-2 mb-0 text-4xl select-none">
            <span className="my-auto">
              <a
                href="https://www.youtube.com/watch?v=WzZPPXfYSvE"
                className="no-underline"
                target="_blank"
              >
                🐀&nbsp;
              </a>
            </span>
            <div className="flex flex-col text-center">
              <span>Nikola Kubiczek</span>
              <span className="text-sm font-semibold text-zinc-500">
                (she/her)
              </span>
            </div>
            <span className="my-auto">
              <a
                href="https://www.youtube.com/watch?v=JsV8EI3c48M"
                className="no-underline"
                target="_blank"
              >
                &nbsp;🦈
              </a>
            </span>
          </h1>
          <b className="font-jetbrains">
            <p className="flex flex-col items-center my-0 font-light text-lime-50">
              <span>me@yaemiku.dev</span>
              <a href="public.asc" target="_blank">
                pgp key
              </a>
              <span className="mt-2 text-xs">click on the emojis !!</span>
              <span className="my-0 text-xs italic text-center">
                i use{' '}
                <a href="https://gitlab.com/yaemiku/dots" target="_blank">
                  arch
                </a>{' '}
                btw
              </span>
            </p>
          </b>
        </div>
      </header>
      <main className="flex flex-col justify-around items-center px-4">
        <figure className="flex flex-col gap-y-6 my-6 max-w-screen-sm">
          <blockquote className="text-xl text-justify bg-clip-text text-transparent bg-gradient-to-br from-[#55CDFC] via-[#F7A8B8] to-[#FFFFFF]">
            Your ol&apos; reliable girl here — coming right up to build your new
            awesome website, rant about the supremacy of functional programming
            languages, show you comically large amounts of rat pics and maybe
            even cuddle together under the supervision of{' '}
            <b>Chief Emotional Support Officer Blåhaj</b>? Jk, jk... Unless??
          </blockquote>

          <div className="grid gap-4 text-sm md:grid-cols-2 font-jetbrains">
            <div className="text-center transition transform-gpu ease-in-out col-span-full p-2 rounded-md border border-zinc-500 bg-gradient-to-r from-[#D60270] via-[#9B4F96] to-[#0038A8]">
              <h1 className="font-semibold">My blog !!</h1>
              wip 💀
            </div>
            {items.map(({ name, class_, link, git, full, desc }, i) => (
              <div
                className={`${
                  git ? 'flex' : ''
                } transition transform-gpu ease-in-out p-2 rounded-md ${
                  !!full ? 'col-span-full' : ''
                } border border-zinc-700 bg-zinc-800 ${class_}`}
                key={i}
              >
                {git ? (
                  <>
                    <div>
                      <h1 className="font-semibold">{name}</h1>
                      {link ? (
                        <a href={link} target="_blank">
                          {link}
                        </a>
                      ) : (
                        <span>{desc}</span>
                      )}
                    </div>

                    <a href={git} className="my-auto ml-auto" target="_blank">
                      <Image src={gitlab} alt="gitlab" className="w-8 h-8" />
                    </a>
                  </>
                ) : (
                  <>
                    <h1 className="font-semibold">{name}</h1>
                    <a href={link} target="_blank">
                      {link}
                    </a>
                  </>
                )}
              </div>
            ))}
            <div
              style={{ backgroundColor: `#${RGB}` }}
              className="flex flex-col items-center col-span-full p-2 rounded-md border border-zinc-700 hover:border-[#7f7f84]"
            >
              <h1 className="font-semibold">Color of the day!</h1>
              <span>
                C: <span className="font-semibold">{Math.round(C * 100)}%</span>{' '}
                M: <span className="font-semibold">{Math.round(M * 100)}%</span>{' '}
                Y: <span className="font-semibold">{Math.round(Y * 100)}%</span>{' '}
                K: <span className="font-semibold">{Math.round(K * 100)}%</span>
              </span>
              <span>
                R: <span className="font-semibold">{R}</span> G:{' '}
                <span className="font-semibold">{G}</span> B:{' '}
                <span className="font-semibold">{B}</span>
              </span>
            </div>
          </div>

          <Image
            src={blahaj}
            alt="blahaj"
            className="mx-auto mt-6 rounded-md"
          />
          <figcaption className="mt-[-1.25rem] text-xs text-center text-zinc-400">
            u/markyminkk on r/BLAHAJ
          </figcaption>
        </figure>
      </main>
      <footer className="my-2 text-center">
        <em>
          <a href="https://git.yaemiku.dev/yaemiku" target="_blank">
            yaemiku
          </a>
          &copy; <span id="year">2023</span>
        </em>
        <br />

        <em>
          Made with{' '}
          <a href="https://nextjs.org" target="_blank">
            NextJS
          </a>
          ,{' '}
          <a href="https://framer.com" target="_blank">
            Framer Motion
          </a>{' '}
          and{' '}
          <a href="https://tailwindcss.com" target="_blank">
            TailwindCSS
          </a>{' '}
        </em>
        <br />
        <em>
          Link to
          <a href="https://picrew.me/image_maker/599056" target="_blank">
            picrew
          </a>
        </em>
        <figure className="my-6 max-w-screen-md select-none">
          <blockquote className="text-xs text-justify text-zinc-400">
            Oh, wretched memory that compels us to remember the paths we took to
            arrive at the present state of affairs! Further: as I lay awake but
            still half dreaming, I felt that my body was not homogeneous, that
            some parts were still those of a boy, and that my head was laughing
            at my leg and ridiculing it, that my leg was laughing at my head,
            that my finger was poking fun at my heart, my heart at my brain,
            that my nose was thumbing itself at my eye, my eye chuckling and
            bellowing at my nose — and all my parts were wildly raping each
            other in an all-encompassing and piercing state of pan-mockery. Nor
            did my fear lessen one iota when I reached full consciousness and
            began reflecting on my life. On the contrary, it intensified even as
            it was interrupted (or accentuated) by a giggle my mouth could not
            hold back. I was halfway down the path of my life when I found
            myself in a dark forest.
          </blockquote>
          <figcaption className="mt-2 text-xs text-right text-zinc-700">
            ——— Witold Gombrowicz, Ferdydurke
          </figcaption>
        </figure>
      </footer>
    </div>
  );
}
